@@ -30,7 +30,7 @@ PERFORMANCE OF THIS SOFTWARE.
 ******************************************************************/
 /*
  * Python MQ Extension. Low level mqi wrappers. These present a
- * low-level interface to the MQI 'C' library. 
+ * low-level interface to the MQI 'C' library.
  *
  * Author: L. Smithson (lsmithson@open-networks.co.uk)
  * Author: Dariusz Suchojad (dsuch at gefira.pl)
@@ -44,8 +44,8 @@ PERFORMANCE OF THIS SOFTWARE.
  *
  *
  */
- 
-static char __version__[] = "1.0.1";
+
+static char __version__[] = "1.1";
 
 static char pymqe_doc[] = " \
 pymqe - A Python MQ Extension.  This presents a low-level Python \
@@ -78,9 +78,9 @@ it is set to 'server'.\
 #include <cmqc.h>
 #include <cmqxc.h>
 
-/* 
+/*
  * 64bit suppport courtesy of Brent S. Elmer, Ph.D. (mailto:webe3vt@aim.com)
- * 
+ *
  * On 64 bit machines when MQ is compiled 64bit, MQLONG is an int defined
  * in /opt/mqm/inc/cmqc.h or wherever your MQ installs to.
  *
@@ -148,7 +148,7 @@ static PyObject * pymqe_MQCONN(PyObject *self, PyObject *args) {
   char *name;
   MQHCONN handle;
   MQLONG compCode, compReason;
-  
+
   if (!PyArg_ParseTuple(args, "s", &name)) {
     return NULL;
   }
@@ -177,18 +177,18 @@ NOTE: The argument mqcd refers to the MQI MQCD structure, not MQCNO. \
 ";
 
 static PyObject * pymqe_MQCONNX(PyObject *self, PyObject *args) {
-  char*	name = 0;
+  char*    name = 0;
   MQHCONN handle;
   MQLONG compCode, compReason;
-  char*	mqcdBuf = 0;
+  char*    mqcdBuf = 0;
   int mqcdBufLen = 0;
   MQCNO connectOpts = {MQCNO_DEFAULT};
-  
+
   /*  Note: MQLONG is an int on 64 bit platforms and MQHCONN is an MQLONG
    */
-  
+
   long lOptions = MQCNO_NONE;
-  
+
 #ifdef PYMQI_FEATURE_SSL
   char *mqscoBuf = 0;
   int mqscoBufLen = 0;
@@ -203,12 +203,12 @@ static PyObject * pymqe_MQCONNX(PyObject *self, PyObject *args) {
   if (!PyArg_ParseTuple(args, "sls#", &name, &lOptions, &mqcdBuf, &mqcdBufLen)) {
     return 0;
   }
-#endif  
+#endif
 
   if (checkArgSize(mqcdBufLen, PYMQI_MQCD_SIZEOF, "MQCD")) {
     return NULL;
   }
-      
+
   /*
    * Setup client connection fields appropriate to the version of MQ
    * we've been built with.
@@ -216,13 +216,13 @@ static PyObject * pymqe_MQCONNX(PyObject *self, PyObject *args) {
 #ifdef PYMQI_FEATURE_SSL
   connectOpts.Version = MQCNO_VERSION_4;
   connectOpts.SSLConfigPtr =  (MQSCO*)mqscoBuf;
-#else  
+#else
   connectOpts.Version = MQCNO_VERSION_2;
-#endif 
+#endif
 
   connectOpts.ClientConnPtr = (MQCD*)mqcdBuf;
   connectOpts.Options = (MQLONG) lOptions;
-  
+
   Py_BEGIN_ALLOW_THREADS
   MQCONNX(name, &connectOpts, &handle, &compCode, &compReason);
   Py_END_ALLOW_THREADS
@@ -241,17 +241,17 @@ Manager. The tuple (comp, reason) is returned. \
 static PyObject * pymqe_MQDISC(PyObject *self, PyObject *args) {
   MQHCONN handle;
   MQLONG compCode, compReason;
-  
+
   /*  Note: MQLONG is an int on 64 bit platforms and MQHCONN is an MQLONG
    */
-  
+
   long lHandle;
-  
+
   if (!PyArg_ParseTuple(args, "l", &lHandle)) {
     return NULL;
   }
   handle = (MQHCONN) lHandle;
-  
+
   Py_BEGIN_ALLOW_THREADS
   MQDISC(&handle, &compCode, &compReason);
   Py_END_ALLOW_THREADS
@@ -276,7 +276,7 @@ is raised. \
 " ;
 
 static PyObject *pymqe_MQOPEN(PyObject *self, PyObject *args) {
-  
+
   MQOD *qDescP;
   char *qDescBuffer;
   int qDescBufferLength;
@@ -286,15 +286,15 @@ static PyObject *pymqe_MQOPEN(PyObject *self, PyObject *args) {
   long lOptions, lQmgrHandle;
 
   if (!PyArg_ParseTuple(args, "ls#l", &lQmgrHandle, &qDescBuffer,
-			&qDescBufferLength, &lOptions)) {
+            &qDescBufferLength, &lOptions)) {
     return NULL;
   }
-  
+
   qDescP = (MQOD *)qDescBuffer;
   if (checkArgSize(qDescBufferLength, PYMQI_MQOD_SIZEOF, "MQOD")) {
     return NULL;
   }
-  
+
   Py_BEGIN_ALLOW_THREADS
     MQOPEN((MQHCONN)lQmgrHandle, qDescP, (MQLONG) lOptions, &qHandle, &compCode, &compReason);
   Py_END_ALLOW_THREADS
@@ -315,12 +315,12 @@ returned. \
 static PyObject * pymqe_MQCLOSE(PyObject *self, PyObject *args) {
   MQHOBJ qHandle;
   MQLONG compCode, compReason;
-  
+
   /* Note: MQLONG is an int on 64 bit platforms and MQHCONN and MQHOBJ are MQLONG
    */
 
   long lOptions, lQmgrHandle, lqHandle;
-  
+
   if (!PyArg_ParseTuple(args, "lll", &lQmgrHandle, &lqHandle, &lOptions)) {
     return NULL;
   }
@@ -356,18 +356,18 @@ static PyObject *mqputN(int put1Flag, PyObject *self, PyObject *args) {
   if (!put1Flag) {
     /* PUT call, expects qHandle for an open q */
     if (!PyArg_ParseTuple(args, "lls#s#s#", &lQmgrHandle, &lqHandle,
-			  &mDescBuffer, &mDescBufferLength,
-			  &putOptsBuffer, &putOptsBufferLength,
-			  &msgBuffer, &msgBufferLength)) {
+              &mDescBuffer, &mDescBufferLength,
+              &putOptsBuffer, &putOptsBufferLength,
+              &msgBuffer, &msgBufferLength)) {
       return NULL;
     }
   } else {
     /* PUT1 call, expects od for a queue to be opened */
     if (!PyArg_ParseTuple(args, "ls#s#s#s#", &lQmgrHandle,
-			  &qDescBuffer, &qDescBufferLength,
-			  &mDescBuffer, &mDescBufferLength,
-			  &putOptsBuffer, &putOptsBufferLength,
-			  &msgBuffer, &msgBufferLength)) {
+              &qDescBuffer, &qDescBufferLength,
+              &mDescBuffer, &mDescBufferLength,
+              &putOptsBuffer, &putOptsBufferLength,
+              &msgBuffer, &msgBufferLength)) {
       return NULL;
 
     }
@@ -376,7 +376,7 @@ static PyObject *mqputN(int put1Flag, PyObject *self, PyObject *args) {
     }
     qDescP = (MQOD *)qDescBuffer;
   }
-  
+
   if (checkArgSize(mDescBufferLength, PYMQI_MQMD_SIZEOF, "MQMD")) {
     return NULL;
   }
@@ -389,20 +389,20 @@ static PyObject *mqputN(int put1Flag, PyObject *self, PyObject *args) {
   if (!put1Flag) {
     Py_BEGIN_ALLOW_THREADS
     MQPUT((MQHCONN) lQmgrHandle, (MQHOBJ) lqHandle, mDescP, pmoP, (MQLONG) msgBufferLength, msgBuffer,
-	  &compCode, &compReason);
+      &compCode, &compReason);
     Py_END_ALLOW_THREADS
   } else {
     Py_BEGIN_ALLOW_THREADS
     MQPUT1((MQHCONN) lQmgrHandle, qDescP, mDescP, pmoP, (MQLONG) msgBufferLength, msgBuffer,
-	   &compCode, &compReason);
+       &compCode, &compReason);
     Py_END_ALLOW_THREADS
   }
   return Py_BuildValue("(s#s#ll)", mDescP, PYMQI_MQMD_SIZEOF,
-		       pmoP, PYMQI_MQPMO_SIZEOF, (long) compCode, (long) compReason);
+               pmoP, PYMQI_MQPMO_SIZEOF, (long) compCode, (long) compReason);
 }
 
 
-static char pymqe_MQPUT__doc__[] = 
+static char pymqe_MQPUT__doc__[] =
 "MQPUT(qMgr, qHandle, mDesc, options, msg) \
  \
 Calls the MQI MQPUT(qMgr, qHandle, mDesc, putOpts, msg) function to \
@@ -423,7 +423,7 @@ static PyObject *pymqe_MQPUT(PyObject *self, PyObject *args) {
 }
 
 
-static char pymqe_MQPUT1__doc__[] = 
+static char pymqe_MQPUT1__doc__[] =
 "MQPUT1(qMgr, qDesc, mDesc, options, msg) \
  \
 Calls the MQI MQPUT1(qMgr, qDesc, mDesc, putOpts, msg) function to put \
@@ -448,7 +448,7 @@ static PyObject *pymqe_MQPUT1(PyObject *self, PyObject *args) {
 }
 
 
-static char pymqe_MQGET__doc__[] = 
+static char pymqe_MQGET__doc__[] =
 "MQGET(qMgr, qHandle, mDesc, getOpts, maxlen) \
  \
 Calls the MQI MQGET(qMgr, qHandle, mDesc, getOpts, maxlen) function to \
@@ -486,8 +486,8 @@ static PyObject *pymqe_MQGET(PyObject *self, PyObject *args) {
   long lQmgrHandle, lqHandle;
 
   if (!PyArg_ParseTuple(args, "lls#s#l", &lQmgrHandle, &lqHandle,
-			&mDescBuffer, &mDescBufferLength,
-			&getOptsBuffer, &getOptsBufferLength, &maxLength)) {
+            &mDescBuffer, &mDescBufferLength,
+            &getOptsBuffer, &getOptsBufferLength, &maxLength)) {
     return NULL;
   }
   if (checkArgSize(mDescBufferLength, PYMQI_MQMD_SIZEOF, "MQMD")) {
@@ -509,7 +509,7 @@ static PyObject *pymqe_MQGET(PyObject *self, PyObject *args) {
   actualLength = 0;
   Py_BEGIN_ALLOW_THREADS
   MQGET((MQHCONN) lQmgrHandle, (MQHOBJ) lqHandle, mDescP, gmoP, (MQLONG) maxLength, msgBuffer, &actualLength,
-	&compCode, &compReason);
+    &compCode, &compReason);
   Py_END_ALLOW_THREADS
 
   /*
@@ -522,10 +522,10 @@ static PyObject *pymqe_MQGET(PyObject *self, PyObject *args) {
   } else {
     returnLength = actualLength;
   }
-  
+
   rv = Py_BuildValue("(s#s#s#lll)", msgBuffer, (int) returnLength,
-		     mDescP, PYMQI_MQMD_SIZEOF, gmoP, PYMQI_MQGMO_SIZEOF,
-		     (long) actualLength, (long) compCode, (long) compReason);
+             mDescP, PYMQI_MQMD_SIZEOF, gmoP, PYMQI_MQGMO_SIZEOF,
+             (long) actualLength, (long) compCode, (long) compReason);
   free(msgBuffer);
   return rv;
 }
@@ -567,9 +567,9 @@ returned. \
 
 static PyObject * pymqe_MQCMIT(PyObject *self, PyObject *args) {
   MQLONG compCode, compReason;
-  
+
   long lHandle;
-  
+
   if (!PyArg_ParseTuple(args, "l", &lHandle)) {
     return NULL;
   }
@@ -589,9 +589,9 @@ returned. \
 
 static PyObject * pymqe_MQBACK(PyObject *self, PyObject *args) {
   MQLONG compCode, compReason;
-  
+
   long lHandle;
-  
+
   if (!PyArg_ParseTuple(args, "l", &lHandle)) {
     return NULL;
   }
@@ -628,21 +628,21 @@ static PyObject *pymqe_MQINQ(PyObject *self, PyObject *args) {
   MQLONG charAttrCount = 0;
   MQCHAR charAttrs[MAX_CHARATTR_LENGTH];
   PyObject *retVal = NULL;
-  
+
   long lQmgrHandle, lObjHandle, lSelectors[1];
 
   if (!PyArg_ParseTuple(args, "lll", &lQmgrHandle, &lObjHandle, lSelectors)) {
     return NULL;
   }
   selectors[0] = (MQLONG) lSelectors[0];
-  
+
   if ((selectors[0] >= MQIA_FIRST) && (selectors[0] <= MQIA_LAST)) {
     intAttrCount = 1;
   } else {
     charAttrCount = sizeof(charAttrs) -1;
     memset(charAttrs, 0, sizeof(charAttrs));
   }
-  
+
   Py_BEGIN_ALLOW_THREADS
   MQINQ((MQHCONN) lQmgrHandle, (MQHOBJ) lObjHandle, selectorCount, selectors,
         intAttrCount, intAttrs, charAttrCount, charAttrs, &compCode, &compReason);
@@ -674,7 +674,7 @@ static PyObject *pymqe_MQSET(PyObject *self, PyObject *args) {
   MQLONG charAttrCount = 0;
   MQCHAR charAttrs[MAX_CHARATTR_LENGTH];
   PyObject *attrArg = NULL;
-  
+
   long lQmgrHandle, lObjHandle, lSelectors[1];
 
   if (!PyArg_ParseTuple(args, "lllO", &lQmgrHandle, &lObjHandle, lSelectors, &attrArg)) {
@@ -695,9 +695,9 @@ static PyObject *pymqe_MQSET(PyObject *self, PyObject *args) {
       return NULL;
     }
     strncpy(charAttrs, PyString_AsString(attrArg), MAX_CHARATTR_LENGTH);
-    charAttrCount = strlen(charAttrs);
+    charAttrCount = (MQLONG)strlen(charAttrs); // xx
   }
-  
+
   Py_BEGIN_ALLOW_THREADS
   MQSET((MQHCONN) lQmgrHandle, (MQHOBJ) lObjHandle, selectorCount, selectors,
         intAttrCount, intAttrs, charAttrCount, charAttrs, &compCode, &compReason);
@@ -737,17 +737,21 @@ static PyObject *pymqe_mqaiExecute(PyObject *self, PyObject *args) {
     PyObject* argDict = 0;
     MQLONG compCode, compReason;
     PyObject *argKeys;
-    MQHBAG adminBag = MQHB_UNUSABLE_HBAG;  
+    MQHBAG adminBag = MQHB_UNUSABLE_HBAG;
     MQHBAG responseBag = MQHB_UNUSABLE_HBAG;
     MQHBAG resultBag;
     PyObject *resultsList;
 
+    PyObject *pyItemIntVal;
+    PyObject *pyItemStrVal;
+    PyObject *returnValue;
+
     long lQmgrHandle, lCmdCode;
-  
+
     if(!PyArg_ParseTuple(args, "ll|O", &lQmgrHandle, &lCmdCode, &argDict)) {
         return NULL;
     }
-    
+
     if(argDict && !PyDict_Check(argDict)) {
         PyErr_SetString(ErrorObj, "args is not a dictionary");
         return NULL;
@@ -758,7 +762,7 @@ static PyObject *pymqe_mqaiExecute(PyObject *self, PyObject *args) {
         PyErr_SetString(ErrorObj, "Can't create results list");
         return NULL;
     }
-  
+
     do {
 
         /*
@@ -768,75 +772,77 @@ static PyObject *pymqe_mqaiExecute(PyObject *self, PyObject *args) {
         if(compCode != MQCC_OK) {
             break;
         }
-        
+
         mqCreateBag(MQCBO_ADMIN_BAG, &responseBag, &compCode, &compReason);
         if (compCode != MQCC_OK) {
             break;
         }
-        
+
         /*
          * For each arg key/value pair, create the appopriate type and add
          * it to the bag.
          */
-        argKeys = PyDict_Keys(argDict);
-        if(argDict && (argKeys)) {
-            
-            MQLONG paramType = 0;
-            MQLONG intArg = 0;
-            MQCHAR *strArg = "";
-            
-            int nKeys = PyList_Size(argKeys); /* Owned ref */ 
-            int i;
-        
-            for(i = 0; i < nKeys; i++) {
-                PyObject *key = PyList_GetItem(argKeys, i);      /* Borrowed ref */
-                PyObject *value = PyDict_GetItem(argDict, key);  /* Borrowed ref */
-        
-                /*
-                 * The key ought to be a int or long. Blow up if it isn't
-                 */
-                if(!PyLong_Check(key) && !PyInt_Check(key)) {
-                    PyObject *keyStr = PyObject_Str(key);  /* Owned ref */
-                    PyErr_Format(ErrorObj, "Argument: %s is not integer", PyString_AsString(keyStr));
-                    Py_XDECREF(keyStr);
-                    Py_DECREF(resultsList);
-                    cleanupBags(adminBag, responseBag);
-                    return NULL;
-                }
-                else {
-                    paramType = PyLong_Check(key) ? PyLong_AsLong(key) : PyInt_AsLong(key);
-                }
-            
-                /*
-                 * Now get the value. It must be either a int/long or a string.
-                 */
-                 if (PyLong_Check(value)) {
-                     intArg = PyLong_AsLong(value);
-                     mqAddInteger(adminBag, paramType, intArg, &compCode, &compReason);
-                 } else if (PyInt_Check(value)) {
-                     intArg = PyInt_AsLong(value);
-                     mqAddInteger(adminBag, paramType, intArg, &compCode, &compReason);
+        if(argDict) {
+          argKeys = PyDict_Keys(argDict);
+          if(argDict && (argKeys)) {
+
+              MQLONG paramType = 0;
+              MQLONG intArg = 0;
+              MQCHAR *strArg = "";
+
+              int nKeys = (int)PyList_Size(argKeys); /* Owned ref */ // xx
+              int i;
+
+              for(i = 0; i < nKeys; i++) {
+                  PyObject *key = PyList_GetItem(argKeys, i);      /* Borrowed ref */
+                  PyObject *value = PyDict_GetItem(argDict, key);  /* Borrowed ref */
+
+                  /*
+                   * The key ought to be a int or long. Blow up if it isn't
+                   */
+                  if(!PyLong_Check(key) && !PyInt_Check(key)) {
+                      PyObject *keyStr = PyObject_Str(key);  /* Owned ref */
+                      PyErr_Format(ErrorObj, "Argument: %s is not integer", PyString_AsString(keyStr));
+                      Py_XDECREF(keyStr);
+                      Py_DECREF(resultsList);
+                      cleanupBags(adminBag, responseBag);
+                      return NULL;
+                  }
+                  else {
+                      paramType = PyLong_Check(key) ? PyLong_AsLong(key) : PyInt_AsLong(key);
+                  }
+
+                  /*
+                   * Now get the value. It must be either a int/long or a string.
+                   */
+                   if (PyLong_Check(value)) {
+                       intArg = PyLong_AsLong(value);
+                       mqAddInteger(adminBag, paramType, intArg, &compCode, &compReason);
+                   } else if (PyInt_Check(value)) {
+                       intArg = PyInt_AsLong(value);
+                       mqAddInteger(adminBag, paramType, intArg, &compCode, &compReason);
+                   }
+                   else if (PyString_Check(value)) {
+                       strArg = PyString_AsString(value);
+                       mqAddString(adminBag, paramType, MQBL_NULL_TERMINATED, strArg, &compCode, &compReason);
+                  } else {
+                      PyObject *keyStr = PyObject_Str(key);    /* Owned ref */
+                      PyObject *valStr = PyObject_Str(value);  /* Owned ref */
+                      PyErr_Format(ErrorObj, "Value %s for key %s is neither a long or string",
+                                   PyString_AsString(valStr), PyString_AsString(keyStr));
+                      Py_XDECREF(keyStr);
+                      Py_XDECREF(valStr);
+                      Py_DECREF(resultsList);
+                      cleanupBags(adminBag, responseBag);
+                      return NULL;
                  }
-                 else if (PyString_Check(value)) {
-                     strArg = PyString_AsString(value);
-                     mqAddString(adminBag, paramType, MQBL_NULL_TERMINATED, strArg, &compCode, &compReason); 
-                } else {
-                    PyObject *keyStr = PyObject_Str(key);    /* Owned ref */
-                    PyObject *valStr = PyObject_Str(value);  /* Owned ref */
-                    PyErr_Format(ErrorObj, "Value %s for key %s is neither a long or string",
-                                 PyString_AsString(valStr), PyString_AsString(keyStr));
-                    Py_XDECREF(keyStr);
-                    Py_XDECREF(valStr);
-                    Py_DECREF(resultsList);
-                    cleanupBags(adminBag, responseBag);
-                    return NULL;
-               }
-               if(compCode != MQCC_OK) {
-                   break;
-               }
-            }
+                 if(compCode != MQCC_OK) {
+                     break;
+                 }
+              }
+          }
+          Py_XDECREF(argKeys);
         }
-        Py_XDECREF(argKeys);
 
         /*
          * Everything bagged up -- Now execute the command
@@ -845,7 +851,7 @@ static PyObject *pymqe_mqaiExecute(PyObject *self, PyObject *args) {
             mqExecute((MQHCONN) lQmgrHandle, (MQLONG) lCmdCode, MQHB_NONE, adminBag, responseBag,
                       MQHO_NONE, MQHO_NONE, &compCode, &compReason);
         Py_END_ALLOW_THREADS
-        
+
         if(compCode != MQCC_OK) {
             /*
              * If the command execution failed at the Queue Manager, get
@@ -865,7 +871,7 @@ static PyObject *pymqe_mqaiExecute(PyObject *self, PyObject *args) {
             }
         break;
         }
-        
+
         else {
             /*
              * Command executed OK. Get each user bag (if any) from the
@@ -875,21 +881,21 @@ static PyObject *pymqe_mqaiExecute(PyObject *self, PyObject *args) {
              */
              MQLONG numberOfBags;
              mqCountItems(responseBag, MQHA_BAG_HANDLE, &numberOfBags, &compCode, &compReason);
-             
+
              if(compCode != MQCC_OK) {
                  break;
              }
-             
+
              else {
                 int i;
                 for (i = 0; i < numberOfBags; i++) {
                     MQHBAG attrsBag;
                     mqInquireBag(responseBag, MQHA_BAG_HANDLE, i, &attrsBag, &compCode, &compReason);
-                    
+
                     if (compCode != MQCC_OK) {
                         break;
                     }
-                    
+
                     else {
                         /*
                          * Query each item in the bag to find its type. We're
@@ -898,25 +904,25 @@ static PyObject *pymqe_mqaiExecute(PyObject *self, PyObject *args) {
                          */
                         MQLONG numberOfItems;
                         mqCountItems(attrsBag, MQSEL_ALL_USER_SELECTORS, &numberOfItems, &compCode, &compReason);
-                        
+
                         if(compCode != MQCC_OK) {
                             break;
-                        } 
-                        
+                        }
+
                         else {
-                            
+
                             int j;
                             MQLONG itemType;
                             MQLONG selector;
                             PyObject *resultsDict = PyDict_New();  /* Owned ref - returned to interp */
-                  
+
                             if(!resultsDict) {
                                 PyErr_SetString(ErrorObj, "Can't make results dict");
                                 cleanupBags(adminBag, responseBag);
                                 Py_DECREF(resultsList);
                                 return NULL;
                             }
-                    
+
                             for(j = 0; j < numberOfItems; j++) {
                                 /*
                                  * Dratted IBM docs have the selector & itemType params swapped!
@@ -933,7 +939,7 @@ static PyObject *pymqe_mqaiExecute(PyObject *self, PyObject *args) {
                                      * these are 'stolen' when added to the dict.
                                      */
                                     PyObject *key = PyLong_FromLong(selector);  /* Owned ref */
-                                    
+
                                     if(!key) {
                                         PyErr_SetString(ErrorObj, "Can't make results dict key");
                                         cleanupBags(adminBag, responseBag);
@@ -941,36 +947,36 @@ static PyObject *pymqe_mqaiExecute(PyObject *self, PyObject *args) {
                                         Py_XDECREF(resultsDict);
                                         return NULL;
                                     }
-                                    
+
                                     if(itemType == MQIT_INTEGER) {
                                         MQLONG itemIntVal;
                                         mqInquireInteger(attrsBag, MQSEL_ANY_USER_SELECTOR, j, &itemIntVal, &compCode, &compReason);
-                                        
-                                        PyObject *pyItemIntVal = PyLong_FromLong(itemIntVal);
+
+                                        pyItemIntVal = PyLong_FromLong(itemIntVal);
                                         PyDict_SetItem(resultsDict, key, pyItemIntVal);
-                                        
+
                                         Py_XDECREF(pyItemIntVal);
                                         Py_XDECREF(key);
                                     }
-                                    
+
                                     else if(itemType == MQIT_STRING) {
-                                        
+
                                         MQCHAR *itemStrVal;
                                         MQLONG strLength;
                                         /*
                                          * Two calls are needed - one to get the string
                                          * length, and one to get the string itself.
                                          */
-                                         
-                                        /* 1st call */ 
+
+                                        /* 1st call */
                                         mqInquireString(attrsBag, MQSEL_ANY_USER_SELECTOR, j, 0, 0, &strLength, 0, &compCode, &compReason);
-                                        
+
                                         if(compCode != MQCC_OK && compReason != MQRC_STRING_TRUNCATED) {
                                             break;
                                         }
-                                        
+
                                         strLength++;   /* + one for the Null */
-                                        
+
                                         if(!(itemStrVal = malloc(strLength))) {
                                             PyErr_SetString(ErrorObj, "Out of memory");
                                             cleanupBags(adminBag, responseBag);
@@ -979,24 +985,24 @@ static PyObject *pymqe_mqaiExecute(PyObject *self, PyObject *args) {
                                             Py_XDECREF(key);
                                             return NULL;
                                         }
-                                        
+
                                         /* 2nd call */
                                         mqInquireString(attrsBag, MQSEL_ANY_USER_SELECTOR, j, strLength, itemStrVal,
                                                         &strLength, 0, &compCode, &compReason);
-                                        
+
                                         if(compCode != MQCC_OK) {
                                             break;
                                         }
-                                        
+
                                         itemStrVal[strLength] = 0;
-                                        
-                                        PyObject *pyItemStrVal = PyString_FromString(itemStrVal);
+
+                                        pyItemStrVal = PyString_FromString(itemStrVal);
                                         PyDict_SetItem(resultsDict, key, pyItemStrVal);
-                                        
+
                                         free(itemStrVal);
                                         Py_XDECREF(key);
                                         Py_XDECREF(pyItemStrVal);
-                                        
+
                                     }
                                     else {
                                         /*
@@ -1010,7 +1016,7 @@ static PyObject *pymqe_mqaiExecute(PyObject *self, PyObject *args) {
                                     }
                                 }
                             }
-                            
+
                         /*
                          * Append the results to the returned list
                          */
@@ -1022,13 +1028,13 @@ static PyObject *pymqe_mqaiExecute(PyObject *self, PyObject *args) {
             }
         }
         break;
-    
+
     } while (1);
     cleanupBags(adminBag, responseBag);
-    
-    PyObject *returnValue = Py_BuildValue("(Oll)", resultsList, (long) compCode, (long) compReason);
+
+    returnValue = Py_BuildValue("(Oll)", resultsList, (long) compCode, (long) compReason);
     Py_XDECREF(resultsList);
-    
+
     return returnValue;
 }
 
@@ -1040,10 +1046,10 @@ static PyObject *pymqe_mqaiExecute(PyObject *self, PyObject *args) {
 /* List of methods defined in the module */
 
 static struct PyMethodDef pymqe_methods[] = {
-  {"MQCONN", (PyCFunction)pymqe_MQCONN,	METH_VARARGS, pymqe_MQCONN__doc__},
+  {"MQCONN", (PyCFunction)pymqe_MQCONN,    METH_VARARGS, pymqe_MQCONN__doc__},
   {"MQCONNX", (PyCFunction)pymqe_MQCONNX, METH_VARARGS, pymqe_MQCONNX__doc__},
-  {"MQDISC", (PyCFunction)pymqe_MQDISC,	METH_VARARGS, pymqe_MQDISC__doc__},
-  {"MQOPEN", (PyCFunction)pymqe_MQOPEN,	METH_VARARGS, pymqe_MQOPEN__doc__},
+  {"MQDISC", (PyCFunction)pymqe_MQDISC,    METH_VARARGS, pymqe_MQDISC__doc__},
+  {"MQOPEN", (PyCFunction)pymqe_MQOPEN,    METH_VARARGS, pymqe_MQOPEN__doc__},
   {"MQCLOSE", (PyCFunction)pymqe_MQCLOSE, METH_VARARGS, pymqe_MQCLOSE__doc__},
   {"MQPUT", (PyCFunction)pymqe_MQPUT, METH_VARARGS, pymqe_MQPUT__doc__},
   {"MQPUT1", (PyCFunction)pymqe_MQPUT1, METH_VARARGS, pymqe_MQPUT1__doc__},
@@ -1056,13 +1062,13 @@ static struct PyMethodDef pymqe_methods[] = {
 #ifdef  PYMQI_FEATURE_MQAI
   {"mqaiExecute", (PyCFunction)pymqe_mqaiExecute, METH_VARARGS, pymqe_mqaiExecute__doc__},
 #endif
-  {NULL, (PyCFunction)NULL, 0, NULL}		/* sentinel */
+  {NULL, (PyCFunction)NULL, 0, NULL}        /* sentinel */
 };
 
 
 /* Initialization function for the module (*must* be called initpymqe) */
 
-static char pymqe_module_documentation[] = 
+static char pymqe_module_documentation[] =
 ""
 ;
 
@@ -1071,18 +1077,18 @@ __declspec(dllexport)
 #endif
      void initpymqe(void) {
   PyObject *m, *d;
-	
+
   /* Create the module and add the functions */
   m = Py_InitModule4("pymqe", pymqe_methods,
-		     pymqe_module_documentation,
-		     (PyObject*)NULL,PYTHON_API_VERSION);
+             pymqe_module_documentation,
+             (PyObject*)NULL,PYTHON_API_VERSION);
 
   /* Add some symbolic constants to the module */
   d = PyModule_GetDict(m);
   ErrorObj = PyErr_NewException("pymqe.error", NULL, NULL);
   PyDict_SetItemString(d, "pymqe.error", ErrorObj);
 
-  PyDict_SetItemString(d, "__doc__", PyString_FromString(pymqe_doc)); 
+  PyDict_SetItemString(d, "__doc__", PyString_FromString(pymqe_doc));
   PyDict_SetItemString(d,"__version__", PyString_FromString(__version__));
 
   /*
@@ -1093,13 +1099,13 @@ __declspec(dllexport)
     PyObject *versions = PyList_New(0);
 #ifdef MQCMDL_LEVEL_500
       PyList_Append(versions, PyString_FromString("5.0"));
-#endif      
+#endif
 #ifdef MQCMDL_LEVEL_510
       PyList_Append(versions, PyString_FromString("5.1"));
-#endif      
+#endif
 #ifdef MQCMDL_LEVEL_520
       PyList_Append(versions, PyString_FromString("5.2"));
-#endif      
+#endif
 #ifdef MQCMDL_LEVEL_530
       PyList_Append(versions, PyString_FromString("5.3"));
 #endif
@@ -1116,12 +1122,12 @@ __declspec(dllexport)
   /*
    * Set the client/server build flag
    */
-#if PYQMI_SERVERBUILD == 1 
+#if PYQMI_SERVERBUILD == 1
   PyDict_SetItemString(d,"__mqbuild__", PyString_FromString("server"));
 #else
   PyDict_SetItemString(d,"__mqbuild__", PyString_FromString("client"));
 #endif
-  
+
   /* Check for errors */
   if (PyErr_Occurred())
     Py_FatalError("can't initialize module pymqe");
